@@ -11,4 +11,4 @@ from cosmoglobe.hub import sky_model
 from cosmoglobe.chain.h5 import model_from_chain
 from cosmoglobe.plot import plot
 
-__all__ = ['Class']
+__all__ = ("Class",)
